# SAME Python SDK

> ⚠ This module is experimental and incomplete.

## Overview

Experimental SDK module for use in Jupyter notebooks to help integration with ML DevOps. Refer to the [initial roadmap scenarios](https://github.com/SAME-Project/same-mono-private/issues/7) for more information.
